==> q3-ui-filemanager-3.13.0.tgz: package/lib/ContextMenu/ContextMenu.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _usefulState = require("useful-state");

var _Menu = _interopRequireDefault(require("@material-ui/core/Menu"));

var _Divider = _interopRequireDefault(require("@material-ui/core/Divider"));

var _MenuItem = _interopRequireDefault(require("@material-ui/core/MenuItem"));

var _ContextMenu = _interopRequireDefault(require("./ContextMenu"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

let open;
let close;

const renderWithEvent = props => {
  const eventStub = {
    preventDefault: jest.fn(),
    stopPropagation: jest.fn()
  };
  const el = global.shallow( /*#__PURE__*/_react.default.createElement(_ContextMenu.default, _extends({
    id: "test"
  }, props), callback => {
    callback(eventStub);
    return null;
  }));
  return {
    el,
    eventStub
  };
};

beforeEach(() => {
  open = jest.fn();
  close = jest.fn();

  _usefulState.useOpen.mockReturnValue({
    isOpen: true,
    open,
    close
  });
});
describe('ContextMenu', () => {
  it('should select ID and disable drag when opening the context menu', () => {
    const contextStub = {
      disable: jest.fn(),
      select: jest.fn()
    };
    jest.spyOn(_react.default, 'useContext').mockReturnValue(contextStub);
    Object.values({ // must deconstruct first
      ...renderWithEvent().eventStub,
      ...contextStub,
      open
    }).forEach(mockFn => {
      expect(mockFn).toHaveBeenCalled();
    });
    expect(contextStub.select).toHaveBeenCalledWith('test');
  });
  it('should close menu when not already closed', () => {
    const {
      el,
      eventStub
    } = renderWithEvent();
    el.find(_Menu.default).prop('BackdropProps').onContextMenu(eventStub);
    expect(close).toHaveBeenCalledWith(eventStub);
  });
  it('should render list item with click handler', () => {
    const onClick = jest.fn();
    const {
      el
    } = renderWithEvent({
      items: [{
        divider: true
      }, {
        label: 'test',
        icon: 'icon ',
        onClick
      }]
    });
    const menuItem = el.find(_MenuItem.default);
    expect(el.find(_Divider.default)).toHaveLength(1);
    expect(menuItem).toHaveLength(1);
    expect(menuItem.text()).toMatch('icon test');
    menuItem.props().onClick();
    expect(onClick).toHaveBeenCalled();
  });
  it('should check auth', () => {
    jest.spyOn(_react.default, 'useContext').mockReturnValue({
      canEdit: true,
      canDelete: false,
      disable: jest.fn(),
      select: jest.fn()
    });
    const {
      el
    } = renderWithEvent({
      items: [{
        auth: 'canEdit',
        label: 'testEdit',
        icon: 'icon ',
        onClick: jest.fn()
      }, {
        auth: 'canDelete',
        label: 'testDelete',
        icon: 'icon ',
        onClick: jest.fn()
      }]
    });
    const menuItem = el.find(_MenuItem.default);
    expect(menuItem.length).toBe(2);
    expect(menuItem.first().prop('disabled')).toBeFalsy();
    expect(menuItem.last().prop('disabled')).toBeTruthy();
  });
});

==> q3-ui-filemanager-4.5.13.tgz: package/lib/ContextMenu/ContextMenu.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));
var _usefulState = require("useful-state");
var _Menu = _interopRequireDefault(require("@material-ui/core/Menu"));
var _Divider = _interopRequireDefault(require("@material-ui/core/Divider"));
var _MenuItem = _interopRequireDefault(require("@material-ui/core/MenuItem"));
var _ContextMenu = _interopRequireDefault(require("./ContextMenu"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
let open;
let close;
const renderWithEvent = props => {
  const eventStub = {
    preventDefault: jest.fn(),
    stopPropagation: jest.fn()
  };
  const el = global.shallow( /*#__PURE__*/_react.default.createElement(_ContextMenu.default, _extends({
    id: "test"
  }, props), callback => {
    callback(eventStub);
    return null;
  }));
  return {
    el,
    eventStub
  };
};
beforeEach(() => {
  open = jest.fn();
  close = jest.fn();
  _usefulState.useOpen.mockReturnValue({
    isOpen: true,
    open,
    close
  });
});
describe('ContextMenu', () => {
  it('should select ID and disable drag when opening the context menu', () => {
    const contextStub = {
      disable: jest.fn(),
      select: jest.fn()
    };
    jest.spyOn(_react.default, 'useContext').mockReturnValue(contextStub);
    Object.values({
      // must deconstruct first
      ...renderWithEvent().eventStub,
      ...contextStub,
      open
    }).forEach(mockFn => {
      expect(mockFn).toHaveBeenCalled();
    });
    expect(contextStub.select).toHaveBeenCalledWith('test');
  });
  it('should close menu when not already closed', () => {
    const {
      el,
      eventStub
    } = renderWithEvent();
    el.find(_Menu.default).prop('BackdropProps').onContextMenu(eventStub);
    expect(close).toHaveBeenCalledWith(eventStub);
  });
  it('should render list item with click handler', () => {
    const onClick = jest.fn();
    const {
      el
    } = renderWithEvent({
      items: [{
        divider: true
      }, {
        label: 'test',
        icon: 'icon ',
        onClick
      }]
    });
    const menuItem = el.find(_MenuItem.default);
    expect(el.find(_Divider.default)).toHaveLength(1);
    expect(menuItem).toHaveLength(1);
    expect(menuItem.text()).toMatch('icon test');
    menuItem.props().onClick();
    expect(onClick).toHaveBeenCalled();
  });
  it('should check auth', () => {
    jest.spyOn(_react.default, 'useContext').mockReturnValue({
      canEdit: true,
      canDelete: false,
      disable: jest.fn(),
      select: jest.fn()
    });
    const {
      el
    } = renderWithEvent({
      items: [{
        auth: 'canEdit',
        label: 'testEdit',
        icon: 'icon ',
        onClick: jest.fn()
      }, {
        auth: 'canDelete',
        label: 'testDelete',
        icon: 'icon ',
        onClick: jest.fn()
      }]
    });
    const menuItem = el.find(_MenuItem.default);
    expect(menuItem.length).toBe(2);
    expect(menuItem.first().prop('disabled')).toBeFalsy();
    expect(menuItem.last().prop('disabled')).toBeTruthy();
  });
});
